from qgis._core import QgsGradientStop, QgsMapLayer, QgsHeatmapRenderer, QgsGradientColorRamp
from qgis.utils import iface
from PyQt5.QtGui import QColor

# 获取当前激活图层
layer = iface.activeLayer()

# 确保当前图层有效且是点图层
if not layer or not layer.isValid() or layer.type() != layer.VectorLayer:
    print("当前图层无效或不是点图层!")
else:
    # 打印当前图层的名字
    print(f"正在处理图层: {layer.name()}")

    colour_ramp_gradient = QgsGradientColorRamp()

    # 设置第一个颜色为透明的蓝色
    transparent_blue = QColor(0, 0, 0, 0)  # 透明度为0
    colour_ramp_gradient.setColor1(transparent_blue)
    colour_ramp_gradient.setColor2(QColor(255, 0, 0))

    # 定义颜色渐变的停靠点
    colour_ramp_gradient.setStops([
        QgsGradientStop(0.45, QColor(0, 0, 255)),
        QgsGradientStop(0.55, QColor(0, 255, 255)),
        QgsGradientStop(0.65, QColor(0, 255, 0)),
        QgsGradientStop(0.95, QColor("yellow")),
        QgsGradientStop(1, QColor(255, 0, 0))
    ])
   
    # 创建热力图渲染器并设置颜色渐变
    heatmap_renderer = QgsHeatmapRenderer()
    heatmap_renderer.setRenderQuality(1)
    heatmap_renderer.setWeightExpression("缓冲距离")
    heatmap_renderer.setColorRamp(colour_ramp_gradient)  # 设置热力图的颜色渐变
    heatmap_renderer.setRadius(5)  # 设置热力图的半径（你可以调整此值）

    # 应用渲染器
    layer.setRenderer(heatmap_renderer)

    # 刷新图层以应用样式
    layer.triggerRepaint()

    print(f"热力图渲染已成功应用到图层: {layer.name()}")
